@@ -310,29 +310,31 @@ void PianobarQt::scroll_output () {
 
 void PianobarQt::on_webView_loadFinished() {
     QWebFrame *frame = ui->webView->page()->mainFrame();
-    QWebElementCollection elements = frame->findAllElements(QString("img"));
-    if(elements.count() < 2) {
+    QWebElementCollection elements = frame->findAllElements(QString("div[class=album0]"));
+
+//    foreach(QWebElement element,elements) {
+//
+//        std::cout << "LINES: " << string(element.toOuterXml().toLatin1()) << "\n";
+//    }
+
+    if(elements.count() < 1) {
         ui->nocoverImage->setVisible(true);
     } else{
-        QWebElement element = elements.at(1);
+        QWebElement element = elements.at(0);
 
-        QStringList imgList = element.toOuterXml().split("\"");
-        QString image = imgList.at(1);
+        QStringList imgList = element.toOuterXml().split(" ");
 
+        QString image = QString(imgList.at(2)).mid(5,QString(imgList.at(2)).length()-6);
+//         std::cout << "FUDGEIT" << string(image.toLatin1()) << "\n";
         QUrl imgUrl(image);        
 
         ui->webView->blockSignals(true);
         //        tmpView->blockSignals(true);
         ui->webView->load(imgUrl);
         ui->nocoverImage->setVisible(false);
+        ui->nocoverImage->setShown(false);
         ui->webView->setVisible(true);
-//                std::cout << "FUDGEIT" << string(image.toLatin1()) << "\n";
-        //        foreach(QWebElement element,elements) {
-        //
-        //            std::cout << "FUDGEIT" << string(element.toOuterXml().toLatin1()) << "\n";
-        //        }
 
-        //            ui->webView->setUrl(url);
     }
 
 }
@@ -373,7 +375,7 @@ void PianobarQt::on_cmdExec_data_available() {
 
         QUrl url("http://www.slothradio.com/covers/index.php?adv=1&artist="+artist.remove(stripAscii)+"&album="+album.remove(stripAscii)+"&imgsize=m");
 
-//                std::cout << string(url.toString().toLatin1()) << "\n";
+        //                std::cout << string(url.toString().toLatin1()) << "\n";
 
         ui->webView->blockSignals(false);
         ui->webView->load(url);
